@@ -11,6 +11,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""Defines a VT object and other helper classes."""
+
 import datetime
 import functools
 import re
@@ -76,7 +78,7 @@ class Object:
         "type": <object type>,
         "id": <object id>,
         "links": {
-          "self": "https://www.virustotal.com/api/v3/<collection name>/<object id>"
+          "self": "https://www.virustotal.com/api/v3/<collection name>/<obj id>"
         },
         "attributes": {
           ...
@@ -105,6 +107,9 @@ class Object:
     if 'relationships' in obj_dict:
       obj._relationships = obj_dict['relationships']
 
+    if 'error' in obj_dict:
+      obj._error = obj_dict['error']
+
     return obj
 
   def __init__(self, obj_type, obj_id=None, obj_attributes=None):
@@ -125,6 +130,7 @@ class Object:
 
     self._modified_attrs = []
     self._modified_data = {}
+    self._error = None
 
   def __on_attr_change(self, attr):
     if hasattr(self, '_modified_attrs'):
@@ -132,8 +138,8 @@ class Object:
 
   def __getattribute__(self, attr):
     value = super().__getattribute__(attr)
-    for re in Object.DATE_ATTRIBUTES:
-      if re.match(attr):
+    for r in Object.DATE_ATTRIBUTES:
+      if r.match(attr):
         value = datetime.datetime.utcfromtimestamp(value)
         break
     return value
@@ -178,6 +184,10 @@ class Object:
       return self._relationships
     return {}
 
+  @property
+  def error(self):
+    return self._error
+
   def get(self, attr_name, default=None):
     """Returns an attribute by name.
 
